@@ -11,6 +11,7 @@ import logging
 import logging.handlers
 import tempfile
 import shutil
+from contextlib import contextmanager
 
 
 def initOgler(level=logging.CRITICAL, **kwa):
@@ -36,6 +37,38 @@ def initOgler(level=logging.CRITICAL, **kwa):
     return Ogler(level=level, **kwa)
 
 
+@contextmanager
+def openOgler(cls=None, name="test", temp=True, **kwa):
+    """
+    Context manager wrapper Ogler instances.
+    Defaults to temporary file logs.
+    Context 'with' statements call .close on exit of 'with' block
+
+    Parameters:
+        cls is Class instance of subclass instance
+        name is str name of ogler instance for filename so can have multiple oglers
+             at different paths thar each use different log file directories
+        temp is Boolean, True means open in temporary directory, clear on close
+                Otherwise open in persistent directory, do not clear on close
+
+    Usage:
+
+    with openOgler(name="bob") as ogler:
+        logger = ogler.getLogger()  ....
+
+    with openOgler(name="eve", cls=SubclassedOgler)
+
+    """
+    if cls is None:
+        cls = Ogler
+    try:
+        ogler = cls(name=name, temp=temp, reopen=True, **kwa)
+        yield ogler
+
+    finally:
+        ogler.close()  # if .temp also clears
+
+
 class Ogler():
     """
     Olgery instances retreive and configure loggers from global logging facility
@@ -46,16 +79,24 @@ class Ogler():
     will always return a reference to the same Logger object.
 
     Attributes:
+        .name is str used in file name
         .level is logging severity level
-        .logFilePath is path to log file
+        .temp is Boolean True means use /tmp directory
+        .prefix is str used as part of path prefix and formating
+        .headDirPath is str used as head of path
+        .tailDirpath is str used as tail of path
+        .altTailDirPath is str used a alternate tail of path
+        .dirPath is full directory path
+        .path is full file path
+        .opened is Boolean, True means file is opened Otherwise False
     """
     Prefix = "hio"
     HeadDirPath = "/usr/local/var"  # default in /usr/local/var
     TailDirPath = "log"
     AltHeadDirPath = "~"  #  put in ~ as fallback when desired dir not permitted
     TempHeadDir = "/tmp"
-    TempMidfix = "log_"
-    TempSuffix = "_test"
+    TempPrefix = "test_"
+    TempSuffix = "_temp"
 
     def __init__(self, name='main', level=logging.ERROR, temp=False,
                  prefix=None, headDirPath=None, reopen=False, clear=False):
@@ -77,19 +118,18 @@ class Ogler():
                 DEBUG    10
                 NOTSET    0
 
-            file is Boolean True means create logfile Otherwise not
-            temp is Boolean If file then True means use temp direction
-                                         Otherwise use  headDirpath
+            temp is Boolean True means use /tmp directory If .filed and clear on close
+                            False means use  headDirpath If .filed
+            prefix is str to include in path and logging template
             headDirPath is str for custom headDirPath for log file
-            clear is Boolean True means clear .path when closing in reopen
+            reopen is Booblean True means reopen path if anything changed
+            clear is Boolean True means clear .dirPath when closing in reopen
         """
         self.name = name if name else 'main'  # for file name
         self.level = level  # basic logger level
         self.temp = True if temp else False
         self.prefix = prefix if prefix is not None else self.Prefix
         self.headDirPath = headDirPath if headDirPath is not None else self.HeadDirPath
-        self.tailDirPath = os.path.join(self.prefix, self.TailDirPath)
-        self.altTailDirPath = os.path.join(".{}".format(self.prefix), self.TailDirPath)
         self.dirPath = None
         self.path = None
         self.opened = False
@@ -161,38 +201,46 @@ class Ogler():
                 self.name = name
 
             if self.temp:
-                prefix = "{}_{}".format(self.prefix, self.TempMidfix)
-                headDirPath = tempfile.mkdtemp(prefix=prefix,
-                                               suffix=self.TempSuffix,
-                                               dir="/tmp")
-                self.dirPath = os.path.abspath(
-                                    os.path.join(headDirPath,
-                                                 self.tailDirPath))
-                os.makedirs(self.dirPath)
+                dirPath = os.path.abspath(
+                                        os.path.join(self.TempHeadDir,
+                                                    self.prefix,
+                                                    self.TailDirPath))
+                if not os.path.exists(dirPath):
+                    os.makedirs(dirPath)  # mkdtemp only makes last dir
+                self.dirPath = tempfile.mkdtemp(prefix=self.TempPrefix,
+                                                suffix=self.TempSuffix,
+                                                dir=dirPath)
 
             else:
                 self.dirPath = os.path.abspath(
-                                    os.path.expanduser(
-                                        os.path.join(self.headDirPath,
-                                                     self.tailDirPath)))
+                        os.path.expanduser(
+                                            os.path.join(self.headDirPath,
+                                                         self.prefix,
+                                                         self.TailDirPath)))
 
                 if not os.path.exists(self.dirPath):
                     try:
                         os.makedirs(self.dirPath)
-                    except OSError as ex:
-                        headDirPath = self.AltHeadDirPath
+                    except OSError as ex:  # can't make dir
+                        # use alt=user's directory instead
+                        prefix = ".{}".format(self.prefix)  # hide it
                         self.dirPath = os.path.abspath(
-                                            os.path.expanduser(
-                                                os.path.join(self.AltHeadDirPath,
-                                                             self.altTailDirPath)))
+                                                os.path.expanduser(
+                                                                os.path.join(self.AltHeadDirPath,
+                                                                             prefix,
+                                                                            self.TailDirPath)))
                         if not os.path.exists(self.dirPath):
                             os.makedirs(self.dirPath)
-                else:
+                else:  # path exists
                     if not os.access(self.dirPath, os.R_OK | os.W_OK):
+                        # but can't access it
+                        # use alt=user's directory instead
+                        prefix = ".{}".format(self.prefix)  # hide it
                         self.dirPath = os.path.abspath(
-                                            os.path.expanduser(
-                                                os.path.join(self.AltHeadDirPath,
-                                                             self.altTailDirPath)))
+                                                os.path.expanduser(
+                                                                os.path.join(self.AltHeadDirPath,
+                                                                             prefix,
+                                                                             self.TailDirPath)))
                         if not os.path.exists(self.dirPath):
                             os.makedirs(self.dirPath)
 
@@ -209,12 +257,12 @@ class Ogler():
 
     def close(self, clear=False):
         """
-        Close lmdb at .env and if clear or .temp then remove lmdb directory at .path
+        Close lmdb at .env and if clear or self.temp then remove directory at .path
         Parameters:
-           clear is boolean, True means clear lmdb directory
+           clear is boolean, True means clear directory
         """
         self.opened = False
-        if clear:
+        if clear or self.temp:
             self.clearDirPath()
 
 
@@ -222,7 +270,7 @@ class Ogler():
         """
         Remove logfile directory at .dirPath
         """
-        if os.path.exists(self.dirPath):
+        if self.dirPath and os.path.exists(self.dirPath):
             shutil.rmtree(self.dirPath)
 
 
